@@ -6,6 +6,8 @@ pub mod get_room_visibility;
 pub mod set_room_visibility;
 
 use js_int::{uint, UInt};
+#[cfg(feature = "unstable-pre-spec")]
+use ruma_events::room::join_rules::JoinRule;
 use ruma_identifiers::{MxcUri, RoomAliasId, RoomId};
 use serde::{Deserialize, Serialize};
 
@@ -53,6 +55,12 @@ pub struct PublicRoomsChunk {
         serde(default, deserialize_with = "ruma_serde::empty_string_as_none")
     )]
     pub avatar_url: Option<MxcUri>,
+
+    /// The joining rule for the room.
+    #[cfg(feature = "unstable-pre-spec")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub join_rule: Option<JoinRule>,
 }
 
 impl PublicRoomsChunk {
@@ -72,6 +80,8 @@ impl PublicRoomsChunk {
             world_readable: false,
             guest_can_join: false,
             avatar_url: None,
+            #[cfg(feature = "unstable-pre-spec")]
+            join_rule: None,
         }
     }
 }
