@@ -54,6 +54,6 @@ impl Request<'_> {
 impl Response {
     /// Creates an empty `Response`.
     pub fn new() -> Self {
-        Self
+        Self {}
     }
 }
